Gnus development mailing list
 help / color / mirror / Atom feed
* nntps and posting.
@ 2006-12-25 12:53 Michaël Cadilhac
  2007-01-08  8:30 ` Michaël Cadilhac
  2007-01-14 12:20 ` Michaël Cadilhac
  0 siblings, 2 replies; 9+ messages in thread
From: Michaël Cadilhac @ 2006-12-25 12:53 UTC (permalink / raw)


[-- Attachment #1: Type: text/plain, Size: 1388 bytes --]

Hi!

I had to made this change to be allowed to post on a nntps server:

--- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
+++ nntp.el	25 Dec 2006 13:48:53 +0100	
@@ -451,10 +451,11 @@
 				wait-for nnheader-callback-function)
 	  ;; If nothing to wait for, still remove possibly echo'ed commands.
 	  ;; We don't have echos if nntp-open-connection-function
 	  ;; is `nntp-open-network-stream', so we skip this in that case.
 	  (unless (or wait-for
-		      (equal nntp-open-connection-function
-			     'nntp-open-network-stream))
+		      (memq nntp-open-connection-function
+			    '(nntp-open-network-stream nntp-open-ssl-stream)))
 	    (nntp-accept-response)
 	    (save-excursion
 	      (set-buffer buffer)
@@ -451,10 +451,11 @@
 	  ;; If nothing to wait for, still remove possibly echo'ed commands.
 	  ;; We don't have echos if nntp-open-connection-function
-	  ;; is `nntp-open-network-stream', so we skip this in that case.
+	  ;; is `nntp-open-network-stream' or `nntp-open-ssl-stream',
+	  ;; so we skip this in that cases.
 	  (unless (or wait-for

Without it, I'm getting stuck after my message is posted (it is,
actually).

I don't know if the patch makes sense, but can we discuss this bug?

-- 
/!\ My mail address has changed, please update your files accordingly.
 |      Michaël `Micha' Cadilhac     |  À quoi bon user des douzes pieds de   |
 |         Epita/LRDE Promo 2007     |  l'alexandrin si ces dames s'épuisent  |
 |  http://michael.cadilhac.name     |  au premier pied qu'elles prennent ?   |
 `--JID: michael.cadilhac@gmail.com--'          -- Jacques_Beauheurt     -  --'

[-- Attachment #2: Type: application/pgp-signature, Size: 188 bytes --]

^ permalink raw reply	[flat|nested] 9+ messages in thread

* Re: nntps and posting.
  2006-12-25 12:53 nntps and posting Michaël Cadilhac
@ 2007-01-08  8:30 ` Michaël Cadilhac
  2007-01-14 12:20 ` Michaël Cadilhac
  1 sibling, 0 replies; 9+ messages in thread
From: Michaël Cadilhac @ 2007-01-08  8:30 UTC (permalink / raw)


[-- Attachment #1: Type: text/plain, Size: 1425 bytes --]

michael@cadilhac.name (Michaël Cadilhac) writes:

> Hi!
>
> I had to made this change to be allowed to post on a nntps server:
>
> --- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
> +++ nntp.el	25 Dec 2006 13:48:53 +0100	
> @@ -451,10 +451,11 @@
>  				wait-for nnheader-callback-function)
>  	  ;; If nothing to wait for, still remove possibly echo'ed commands.
>  	  ;; We don't have echos if nntp-open-connection-function
> -	  ;; is `nntp-open-network-stream', so we skip this in that case.
> +	  ;; is `nntp-open-network-stream' or `nntp-open-ssl-stream',
> +	  ;; so we skip this in that cases.
>  	  (unless (or wait-for
> -		      (equal nntp-open-connection-function
> -			     'nntp-open-network-stream))
> +		      (memq nntp-open-connection-function
> +			    '(nntp-open-network-stream nntp-open-ssl-stream)))
>  	    (nntp-accept-response)
>  	    (save-excursion
>  	      (set-buffer buffer)
>
> Without it, I'm getting stuck after my message is posted (it is,
> actually).
>
> I don't know if the patch makes sense, but can we discuss this bug?

Ping?

-- 
 |      Michaël `Micha' Cadilhac     |  Si les religions etaient aussi tole-  |
 |         Epita/LRDE Promo 2007     |  rantes qu'elles le pretendent, il y   |
 |  http://michael.cadilhac.name     |  a longtemps qu'il n'y en aurait plus  |
 `--JID: michael.cadilhac@gmail.com--'           -- Moustic              -  --'

[-- Attachment #2: Type: application/pgp-signature, Size: 188 bytes --]

^ permalink raw reply	[flat|nested] 9+ messages in thread

* Re: nntps and posting.
  2006-12-25 12:53 nntps and posting Michaël Cadilhac
  2007-01-08  8:30 ` Michaël Cadilhac
@ 2007-01-14 12:20 ` Michaël Cadilhac
  2007-01-17  3:44   ` Katsumi Yamaoka
  1 sibling, 1 reply; 9+ messages in thread
From: Michaël Cadilhac @ 2007-01-14 12:20 UTC (permalink / raw)


[-- Attachment #1: Type: text/plain, Size: 1435 bytes --]

michael@cadilhac.name (Michaël Cadilhac) writes:

> Hi!
>
> I had to made this change to be allowed to post on a nntps server:
>
> --- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
> +++ nntp.el	25 Dec 2006 13:48:53 +0100	
> @@ -451,10 +451,11 @@
>  				wait-for nnheader-callback-function)
>  	  ;; If nothing to wait for, still remove possibly echo'ed commands.
>  	  ;; We don't have echos if nntp-open-connection-function
> -	  ;; is `nntp-open-network-stream', so we skip this in that case.
> +	  ;; is `nntp-open-network-stream' or `nntp-open-ssl-stream',
> +	  ;; so we skip this in that cases.
>  	  (unless (or wait-for
> -		      (equal nntp-open-connection-function
> -			     'nntp-open-network-stream))
> +		      (memq nntp-open-connection-function
> +			    '(nntp-open-network-stream nntp-open-ssl-stream)))
>  	    (nntp-accept-response)
>  	    (save-excursion
>  	      (set-buffer buffer)
>
> Without it, I'm getting stuck after my message is posted (it is,
> actually).
>
> I don't know if the patch makes sense, but can we discuss this bug?

Second ping :-)

-- 
 |      Michaël `Micha' Cadilhac     |  Would someone please DTRT with this,  |
 |         Epita/LRDE Promo 2007     |        then ACK?                       |
 |  http://michael.cadilhac.name     |          -- Richard Stallman           |
 `--JID: michael.cadilhac@gmail.com--'                                   -  --'

[-- Attachment #2: Type: application/pgp-signature, Size: 188 bytes --]

^ permalink raw reply	[flat|nested] 9+ messages in thread

* Re: nntps and posting.
  2007-01-14 12:20 ` Michaël Cadilhac
@ 2007-01-17  3:44   ` Katsumi Yamaoka
  2007-01-29  7:33     ` Michaël Cadilhac
  0 siblings, 1 reply; 9+ messages in thread
From: Katsumi Yamaoka @ 2007-01-17  3:44 UTC (permalink / raw)


>>>>> In <87ac0lrea5.fsf@lrde.org> Michaël Cadilhac wrote:

>> --- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
>> +++ nntp.el	25 Dec 2006 13:48:53 +0100
>> @@ -451,10 +451,11 @@
>>  				wait-for nnheader-callback-function)
>>  	  ;; If nothing to wait for, still remove possibly echo'ed commands.
>>  	  ;; We don't have echos if nntp-open-connection-function
>> -	  ;; is `nntp-open-network-stream', so we skip this in that case.
>> +	  ;; is `nntp-open-network-stream' or `nntp-open-ssl-stream',
>> +	  ;; so we skip this in that cases.
>>  	  (unless (or wait-for
>> -		      (equal nntp-open-connection-function
>> -			     'nntp-open-network-stream))
>> +		      (memq nntp-open-connection-function
>> +			    '(nntp-open-network-stream nntp-open-ssl-stream)))
>>  	    (nntp-accept-response)
>>  	    (save-excursion
>>  	      (set-buffer buffer)
>>
>> Without it, I'm getting stuck after my message is posted (it is,
>> actually).
>>
>> I don't know if the patch makes sense, but can we discuss this bug?

> Second ping :-)

Well, I have no account on nntps servers.  It will be necessary
to verify that this change is harmless for every nntps server.
Can anyone do that?

Regards,



^ permalink raw reply	[flat|nested] 9+ messages in thread

* Re: nntps and posting.
  2007-01-17  3:44   ` Katsumi Yamaoka
@ 2007-01-29  7:33     ` Michaël Cadilhac
  2007-02-13 23:23       ` Michaël Cadilhac
  0 siblings, 1 reply; 9+ messages in thread
From: Michaël Cadilhac @ 2007-01-29  7:33 UTC (permalink / raw)
  To: Katsumi Yamaoka; +Cc: ding

[-- Attachment #1: Type: text/plain, Size: 1620 bytes --]

Katsumi Yamaoka <yamaoka@jpl.org> writes:

>>>>>> In <87ac0lrea5.fsf@lrde.org> Michaël Cadilhac wrote:
>
>>> --- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
>>> +++ nntp.el	25 Dec 2006 13:48:53 +0100
>>> @@ -451,10 +451,11 @@
>>>  				wait-for nnheader-callback-function)
>>>  	  ;; If nothing to wait for, still remove possibly echo'ed commands.
>>>  	  ;; We don't have echos if nntp-open-connection-function
>>> -	  ;; is `nntp-open-network-stream', so we skip this in that case.
>>> +	  ;; is `nntp-open-network-stream' or `nntp-open-ssl-stream',
>>> +	  ;; so we skip this in that cases.
>>>  	  (unless (or wait-for
>>> -		      (equal nntp-open-connection-function
>>> -			     'nntp-open-network-stream))
>>> +		      (memq nntp-open-connection-function
>>> +			    '(nntp-open-network-stream nntp-open-ssl-stream)))
>>>  	    (nntp-accept-response)
>>>  	    (save-excursion
>>>  	      (set-buffer buffer)
>>>
>>> Without it, I'm getting stuck after my message is posted (it is,
>>> actually).
>>>
>>> I don't know if the patch makes sense, but can we discuss this bug?
>
> Well, I have no account on nntps servers.  It will be necessary
> to verify that this change is harmless for every nntps server.
> Can anyone do that?
>
> Regards,

Anyone?..

-- 
 |      Michaël `Micha' Cadilhac     |  Un certain Blaise Pascal              |
 |         Epita/LRDE Promo 2007     |    etc... etc...                       |
 |  http://michael.cadilhac.name     |  -- Prévert (Les paris stupides)       |
 `--JID: michael.cadilhac@gmail.com--'                                   -  --'

[-- Attachment #2: Type: application/pgp-signature, Size: 188 bytes --]

^ permalink raw reply	[flat|nested] 9+ messages in thread

* Re: nntps and posting.
  2007-01-29  7:33     ` Michaël Cadilhac
@ 2007-02-13 23:23       ` Michaël Cadilhac
  2007-02-14  3:24         ` Katsumi Yamaoka
  0 siblings, 1 reply; 9+ messages in thread
From: Michaël Cadilhac @ 2007-02-13 23:23 UTC (permalink / raw)
  To: Katsumi Yamaoka; +Cc: ding

[-- Attachment #1: Type: text/plain, Size: 1807 bytes --]

michael@cadilhac.name (Michaël Cadilhac) writes:

> Katsumi Yamaoka <yamaoka@jpl.org> writes:
>
>>>>>>> In <87ac0lrea5.fsf@lrde.org> Michaël Cadilhac wrote:
>>
>>>> --- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
>>>> +++ nntp.el	25 Dec 2006 13:48:53 +0100
>>>> @@ -451,10 +451,11 @@
>>>>  				wait-for nnheader-callback-function)
>>>>  	  ;; If nothing to wait for, still remove possibly echo'ed commands.
>>>>  	  ;; We don't have echos if nntp-open-connection-function
>>>> -	  ;; is `nntp-open-network-stream', so we skip this in that case.
>>>> +	  ;; is `nntp-open-network-stream' or `nntp-open-ssl-stream',
>>>> +	  ;; so we skip this in that cases.
>>>>  	  (unless (or wait-for
>>>> -		      (equal nntp-open-connection-function
>>>> -			     'nntp-open-network-stream))
>>>> +		      (memq nntp-open-connection-function
>>>> +			    '(nntp-open-network-stream nntp-open-ssl-stream)))
>>>>  	    (nntp-accept-response)
>>>>  	    (save-excursion
>>>>  	      (set-buffer buffer)
>>>>
>>>> Without it, I'm getting stuck after my message is posted (it is,
>>>> actually).
>>>>
>>>> I don't know if the patch makes sense, but can we discuss this bug?
>>
>> Well, I have no account on nntps servers.  It will be necessary
>> to verify that this change is harmless for every nntps server.
>> Can anyone do that?
>>
>> Regards,
>
> Anyone?..

Gimme a ?P! an ?I! an ?N! a ?G! Intern this and gimme a 'PING! Yeah!

... Well, just pinging.

-- 
 |      Michaël `Micha' Cadilhac     |  All your base are belong to us.       |
 |         Epita/LRDE Promo 2007     |    You have no chance to survive       |
 |  http://michael.cadilhac.name     |       make your time, hahaha.          |
 `--JID: michael.cadilhac@gmail.com--'       -- Zero Wings               -  --'

[-- Attachment #2: Type: application/pgp-signature, Size: 188 bytes --]

^ permalink raw reply	[flat|nested] 9+ messages in thread

* Re: nntps and posting.
  2007-02-13 23:23       ` Michaël Cadilhac
@ 2007-02-14  3:24         ` Katsumi Yamaoka
  2007-02-15 10:39           ` Michaël Cadilhac
  2007-02-27  1:56           ` Katsumi Yamaoka
  0 siblings, 2 replies; 9+ messages in thread
From: Katsumi Yamaoka @ 2007-02-14  3:24 UTC (permalink / raw)
  To: Michaël Cadilhac; +Cc: ding

>>>>> In <877iul7ic6.fsf@lrde.org> Michaël Cadilhac wrote:

>>>>> --- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
>>>>> +++ nntp.el	25 Dec 2006 13:48:53 +0100
>>>>> @@ -451,10 +451,11 @@
>>>>>  				wait-for nnheader-callback-function)
>>>>>  	  ;; If nothing to wait for, still remove possibly echo'ed commands.
>>>>>  	  ;; We don't have echos if nntp-open-connection-function
>>>>> -	  ;; is `nntp-open-network-stream', so we skip this in that case.
>>>>> +	  ;; is `nntp-open-network-stream' or `nntp-open-ssl-stream',
>>>>> +	  ;; so we skip this in that cases.
>>>>>  	  (unless (or wait-for
>>>>> -		      (equal nntp-open-connection-function
>>>>> -			     'nntp-open-network-stream))
>>>>> +		      (memq nntp-open-connection-function
>>>>> +			    '(nntp-open-network-stream nntp-open-ssl-stream)))
>>>>>  	    (nntp-accept-response)
>>>>>  	    (save-excursion
>>>>>  	      (set-buffer buffer)

[...]

> Gimme a ?P! an ?I! an ?N! a ?G! Intern this and gimme a 'PING! Yeah!
> ... Well, just pinging.

Let us do it and wait for the response.  I've installed the
patch in the trunk.  What I can do when someone complains is
only to remove it, though.

Regards,



^ permalink raw reply	[flat|nested] 9+ messages in thread

* Re: nntps and posting.
  2007-02-14  3:24         ` Katsumi Yamaoka
@ 2007-02-15 10:39           ` Michaël Cadilhac
  2007-02-27  1:56           ` Katsumi Yamaoka
  1 sibling, 0 replies; 9+ messages in thread
From: Michaël Cadilhac @ 2007-02-15 10:39 UTC (permalink / raw)
  To: Katsumi Yamaoka; +Cc: ding

[-- Attachment #1: Type: text/plain, Size: 1429 bytes --]

Katsumi Yamaoka <yamaoka@jpl.org> writes:

>> In <877iul7ic6.fsf@lrde.org> Michaël Cadilhac wrote:
>
>> --- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
>> +++ nntp.el	25 Dec 2006 13:48:53 +0100
>> @@ -451,10 +451,11 @@
>>  				wait-for nnheader-callback-function)
>>  	  ;; If nothing to wait for, still remove possibly echo'ed commands.
>>  	  ;; We don't have echos if nntp-open-connection-function
>> -	  ;; is `nntp-open-network-stream', so we skip this in that case.
>> +	  ;; is `nntp-open-network-stream' or `nntp-open-ssl-stream',
>> +	  ;; so we skip this in that cases.
>>  	  (unless (or wait-for
>> -		      (equal nntp-open-connection-function
>> -			     'nntp-open-network-stream))
>> +		      (memq nntp-open-connection-function
>> +			    '(nntp-open-network-stream nntp-open-ssl-stream)))
>>  	    (nntp-accept-response)
>>  	    (save-excursion
>>  	      (set-buffer buffer)

> Let us do it and wait for the response.  I've installed the
> patch in the trunk.  What I can do when someone complains is
> only to remove it, though.

Fine for me :-) Thanks!

-- 
 |      Michaël `Micha' Cadilhac     |  Un certain Blaise Pascal              |
 |         Epita/LRDE Promo 2007     |    etc... etc...                       |
 |  http://michael.cadilhac.name     |  -- Prévert (Les paris stupides)       |
 `--JID: michael.cadilhac@gmail.com--'                                   -  --'

[-- Attachment #2: Type: application/pgp-signature, Size: 188 bytes --]

^ permalink raw reply	[flat|nested] 9+ messages in thread

* Re: nntps and posting.
  2007-02-14  3:24         ` Katsumi Yamaoka
  2007-02-15 10:39           ` Michaël Cadilhac
@ 2007-02-27  1:56           ` Katsumi Yamaoka
  1 sibling, 0 replies; 9+ messages in thread
From: Katsumi Yamaoka @ 2007-02-27  1:56 UTC (permalink / raw)
  To: ding

>>>>> In <b4mfy99beux.fsf@jpl.org> Katsumi Yamaoka wrote:

>>>>>> --- nntp.el	05 Feb 2006 14:56:44 +0100	1.31
>>>>>> +++ nntp.el	25 Dec 2006 13:48:53 +0100

[...]

>  	  (unless (or wait-for
> -		      (equal nntp-open-connection-function
> -			     'nntp-open-network-stream))
> +		      (memq nntp-open-connection-function
> +			    '(nntp-open-network-stream nntp-open-ssl-stream)))

> Let us do it and wait for the response.  I've installed the
> patch in the trunk.  What I can do when someone complains is
> only to remove it, though.

I got a response from a person who uses `nntp-open-ssl-stream'
(I Bcc this message to the person).  He wrote that the recent
change stops Gnus from connecting to the nntps server while
Michaël requires it.  It is obvious that some nntps servers
don't echo commands but others do.  So, we have to make it
change the behavior according to the version of the nntps server
automatically or make it customizable by a user.  Since there
seems to be no person to work with nntps servers for the moment,
I've added the following two server variables to the trunk and
the v5-10 branch.

`nntp-never-echoes-commands'
     Non-`nil' means the nntp server never echoes commands.  It is
     reported that some nntps server doesn't echo commands.  So, you
     may want to set this to non-`nil' in the method for such a server
     setting `nntp-open-connection-function' to `nntp-open-ssl-stream'
     for example.  The default value is `nil'.  Note that the
     `nntp-open-connection-functions-never-echo-commands' variable
     overrides the `nil' value of this variable.

`nntp-open-connection-functions-never-echo-commands'
     List of functions that never echo commands.  Add or set a function
     which you set to `nntp-open-connection-function' to this list if
     it does not echo commands.  Note that a non-`nil' value of the
     `nntp-never-echoes-commands' variable overrides this variable.  The
     default value is `(nntp-open-network-stream)'.

It might not have been necessary to have made the later a server
variable but you can use it to have the default value.  For
instance, if all the nntps servers that Michaël connects to don't
echo commands, you can simply set it as follows:

(setq nntp-open-connection-functions-never-echo-commands
      '(nntp-open-network-stream nntp-open-ssl-stream))

Otherwise, you can use `nntp-never-echoes-commands' per server
like the following:

(setq gnus-select-method
      '(nntp "server"
	     (nntp-address "server.example.com")
	     (nntp-open-connection-function nntp-open-ssl-stream)
	     (nntp-never-echoes-commands t)
	     ...
	     ...))

The person who sent a mail to me has nothing to do of course.

Regards,



^ permalink raw reply	[flat|nested] 9+ messages in thread

end of thread, other threads:[~2007-02-27  1:56 UTC | newest]

Thread overview: 9+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2006-12-25 12:53 nntps and posting Michaël Cadilhac
2007-01-08  8:30 ` Michaël Cadilhac
2007-01-14 12:20 ` Michaël Cadilhac
2007-01-17  3:44   ` Katsumi Yamaoka
2007-01-29  7:33     ` Michaël Cadilhac
2007-02-13 23:23       ` Michaël Cadilhac
2007-02-14  3:24         ` Katsumi Yamaoka
2007-02-15 10:39           ` Michaël Cadilhac
2007-02-27  1:56           ` Katsumi Yamaoka

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).